@@ -6,7 +6,7 @@
  *	Copyright (c) 2003-2009, PostgreSQL Global Development Group
  *	Author: Jan Wieck, Afilias USA INC.
  *
- *	
+ *
  *-------------------------------------------------------------------------
  */
 #ifndef SLONIK_H
@@ -53,6 +53,7 @@ typedef struct SlonikStmt_wait_event_s SlonikStmt_wait_event;
 typedef struct SlonikStmt_switch_log_s SlonikStmt_switch_log;
 typedef struct SlonikStmt_sync_s SlonikStmt_sync;
 typedef struct SlonikStmt_sleep_s SlonikStmt_sleep;
+typedef struct SlonikStmt_resubscribe_node_s SlonikStmt_resubscribe_node;
 
 typedef enum
 {
@@ -76,6 +77,7 @@ typedef enum
 	STMT_MOVE_SET,
 	STMT_REPAIR_CONFIG,
 	STMT_RESTART_NODE,
+	STMT_RESUBSCRIBE_NODE,
 	STMT_SET_ADD_SEQUENCE,
 	STMT_SET_ADD_TABLE,
 	STMT_SET_DROP_SEQUENCE,
@@ -197,16 +199,26 @@ struct SlonikStmt_store_node_s
 struct SlonikStmt_drop_node_s
 {
 	SlonikStmt	hdr;
-	int			no_id;
+	int		   *no_id_list;
 	int			ev_origin;
 };
 
+struct failed_node_entry_s
+{
+	int			no_id;
+	int			backup_node;
+	int			temp_backup_node;
+	struct failed_node_entry_s *next;
+	int			num_sets;
+	int			num_nodes;
+};
+
+typedef struct failed_node_entry_s failed_node_entry;
 
 struct SlonikStmt_failed_node_s
 {
 	SlonikStmt	hdr;
-	int			no_id;
-	int			backup_node;
+	failed_node_entry *nodes;
 };
 
 
@@ -404,9 +416,10 @@ struct SlonikStmt_move_set_s
 struct SlonikStmt_ddl_script_s
 {
 	SlonikStmt	hdr;
-	int			ddl_setid;
 	char	   *ddl_fname;
+	char	   *ddl_sql;
 	int			ev_origin;
+	char	   *only_on_nodes;
 	int			only_on_node;
 	FILE	   *ddl_fd;
 };
@@ -426,6 +439,7 @@ struct SlonikStmt_wait_event_s
 	int			wait_confirmed;
 	int			wait_on;
 	int			wait_timeout;
+	int		   *ignore_nodes;
 };
 
 
@@ -448,7 +462,14 @@ struct SlonikStmt_sleep_s
 	int			num_secs;
 };
 
+struct SlonikStmt_resubscribe_node_s
+{
+	SlonikStmt	hdr;
+	int			no_origin;
+	int			no_provider;
+	int			no_receiver;
 
+};
 
 
 extern SlonikScript *parser_script;
@@ -573,7 +594,7 @@ extern int	slonik_switch_log(SlonikStmt_switch_log * stmt);
 extern int	slonik_sync(SlonikStmt_sync * stmt);
 extern int	slonik_sleep(SlonikStmt_sleep * stmt);
 
-extern int	slon_scanint64(char *str, int64 * result);
+extern int	slon_scanint64(char *str, int64 *result);
 
 
 /*
@@ -590,24 +611,24 @@ void		db_notice_recv(void *arg, const char *msg);
 int			db_connect(SlonikStmt * stmt, SlonikAdmInfo * adminfo);
 int			db_disconnect(SlonikStmt * stmt, SlonikAdmInfo * adminfo);
 
-int			db_exec_command(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
-				SlonDString * query);
-int			db_exec_evcommand(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
-				SlonDString * query);
-int			db_exec_evcommand_p(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
-				SlonDString * query, int nParams, const Oid *paramTypes, 
-				const char *const *paramValues, const int *paramLengths, 
-				const int *paramFormats, int resultFormat);
-PGresult   *db_exec_select(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
+int db_exec_command(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
 				SlonDString * query);
+int db_exec_evcommand(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
+				  SlonDString * query);
+int db_exec_evcommand_p(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
+					SlonDString * query, int nParams, const Oid *paramTypes,
+					const char *const * paramValues, const int *paramLengths,
+					const int *paramFormats, int resultFormat);
+PGresult *db_exec_select(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
+			   SlonDString * query);
 int			db_get_version(SlonikStmt * stmt, SlonikAdmInfo * adminfo);
-int			db_check_namespace(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
-				char *clustername);
-int			db_check_requirements(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
-				char *clustername);
+int db_check_namespace(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
+				   char *clustername);
+int db_check_requirements(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
+					  char *clustername);
 int			db_get_nodeid(SlonikStmt * stmt, SlonikAdmInfo * adminfo);
-int			db_begin_xact(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
-						  bool suppress_locking);
+int db_begin_xact(SlonikStmt * stmt, SlonikAdmInfo * adminfo,
+			  bool suppress_locking);
 int			db_commit_xact(SlonikStmt * stmt, SlonikAdmInfo * adminfo);
 int			db_rollback_xact(SlonikStmt * stmt, SlonikAdmInfo * adminfo);
 
@@ -633,7 +654,8 @@ extern int	yylex(void);
 /*
  * Common option types
  */
-typedef enum {
+typedef enum
+{
 	O_ADD_ID,
 	O_ADD_SEQUENCES,
 	O_BACKUP_NODE,
@@ -644,6 +666,7 @@ typedef enum {
 	O_DATE_FORMAT,
 	O_EVENT_NODE,
 	O_EXECUTE_ONLY_ON,
+	O_EXECUTE_ONLY_LIST,
 	O_FILENAME,
 	O_FORWARD,
 	O_FQNAME,
@@ -660,6 +683,7 @@ typedef enum {
 	O_SEQUENCES,
 	O_SERVER,
 	O_SET_ID,
+	O_SQL,
 	O_TAB_ID,
 	O_TABLES,
 	O_TIMEOUT,
@@ -676,21 +700,21 @@ typedef enum {
 /*
  * Common given option list
  */
-typedef struct option_list {
-	option_code	opt_code;
+typedef struct option_list
+{
+	option_code opt_code;
 	int			lineno;
 	int32		ival;
 	char	   *str;
 
 	struct option_list *next;
-} option_list;
+}	option_list;
 
 
 #ifdef WIN32
 #define strtoll _strtoui64
 #define snprintf _snprintf
 #endif
-
 #endif
 /*
  * Local Variables:
